var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var BaseContract_1;
import { ObjectUtils } from "@snickerdoodlelabs/common-utils";
import { EVMContractAddress, EVMAccountAddress, SignerUnavailableError, } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { injectable } from "inversify";
import { errAsync, okAsync, ResultAsync } from "neverthrow";
import { BlockchainErrorMapper, } from "../implementations/BlockchainErrorMapper.js";
import { WrappedTransactionResponse, } from "../interfaces/index.js";
let BaseContract = BaseContract_1 = class BaseContract {
    constructor(providerOrSigner, contractAddress, abi) {
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
        this.abi = abi;
        this.hasSigner = false;
        this.contract = new ethers.Contract(contractAddress, abi, providerOrSigner);
        this.contractAbi = abi;
        // There used to be a method Signer.isSigner() that would do this, but it disappeared entirely in Ethers V6
        this.hasSigner = providerOrSigner["signMessage"] != null;
    }
    getContractAddress() {
        return this.contractAddress;
    }
    getContract() {
        return this.contract;
    }
    assureSigner(functionName) {
        if (!this.hasSigner) {
            return errAsync(new SignerUnavailableError(`Cannot writeToContract function ${functionName}, no signer available. Contract wrapper is in read-only mode.`));
        }
        return okAsync(this.providerOrSigner);
    }
    generateError(error, errorMessage) {
        return BlockchainErrorMapper.buildBlockchainError(error, (msg, err, transaction) => this.generateContractSpecificError(msg, err, transaction || null));
    }
    // Takes the contract's function name and params, submits the transaction and returns a WrappedTransactionResponse
    writeToContract(functionName, functionParams, overrides) {
        return this.assureSigner(functionName).andThen(() => {
            return ResultAsync.fromPromise(this.contract[functionName](...functionParams, {
                ...overrides,
            }), (e) => {
                return e;
            })
                .map((transactionResponse) => {
                return BaseContract_1.buildWrappedTransactionResponse(transactionResponse, this.contractAddress, EVMAccountAddress(this.providerOrSigner?.address), functionName, functionParams, this.contractAbi);
            })
                .mapErr((e) => {
                return BlockchainErrorMapper.buildBlockchainError(e, (msg, reason, e) => this.generateContractSpecificError(msg, reason, e || null));
            });
        });
    }
    // Function to return the correct error type based on mapping of error message
    static buildWrappedTransactionResponse(transactionResponse, contractAddress, signerAddress, functionName, functionParams, contractAbi) {
        return new WrappedTransactionResponse(transactionResponse, contractAddress, signerAddress, functionName, ObjectUtils.serialize(functionParams || []), BaseContract_1.extractFunctionAbi(functionName, contractAbi));
    }
    static extractFunctionAbi(functionName, contractAbi) {
        if (contractAbi == null || contractAbi.abi instanceof Array === false) {
            return "";
        }
        for (const item of contractAbi.abi) {
            if (item.type === "function" && item.name === functionName) {
                return item;
            }
        }
        return "";
    }
};
BaseContract = BaseContract_1 = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String, Object])
], BaseContract);
export { BaseContract };
//# sourceMappingURL=BaseContract.js.map