var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { ConsentContractError, EVMContractAddress, RequestForData, BlockNumber, BigNumberString, Commitment, } from "@snickerdoodlelabs/objects";
import { ethers } from "ethers";
import { injectable } from "inversify";
import { okAsync, ResultAsync, errAsync } from "neverthrow";
import { ERC7529Contract } from "../implementations/ERC7529Contract.js";
import { EConsentRoles, Tag, ContractsAbis, } from "../interfaces/index.js";
let ConsentContract = class ConsentContract extends ERC7529Contract {
    constructor(providerOrSigner, contractAddress, cryptoUtils) {
        super(providerOrSigner, contractAddress, ContractsAbis.ConsentAbi.abi);
        this.providerOrSigner = providerOrSigner;
        this.contractAddress = contractAddress;
        this.cryptoUtils = cryptoUtils;
        this.filters = {
            Transfer: (fromAddress, toAddress) => {
                return this.contract.filters.Transfer(fromAddress, toAddress);
            },
            RequestForData: (ownerAddress) => {
                return this.contract.filters.RequestForData(ownerAddress);
            },
            RequestForDataNoOwner: () => {
                return this.contract.filters.RequestForData();
            },
        };
    }
    getContractAddress() {
        return this.contractAddress;
    }
    optIn(commitment, overrides) {
        return this.writeToContract("optIn", [ethers.toBeArray(commitment)], overrides);
    }
    batchOptIn(commitments, overrides) {
        return this.writeToContract("optIn", commitments.map((commitment) => ethers.toBeArray(commitment)), overrides);
    }
    restrictedOptIn(commitment, nonce, signature, overrides) {
        return this.writeToContract("restrictedOptIn", [nonce, ethers.toBeArray(commitment), signature], overrides);
    }
    requestForData(ipfsCID, overrides) {
        return this.writeToContract("requestForData", [ipfsCID], overrides);
    }
    queryFilter(eventFilter, fromBlock, toBlock) {
        return ResultAsync.fromPromise(this.contract.queryFilter(eventFilter, fromBlock, toBlock), (e) => {
            return this.generateError(e, "Unable to call queryFilter()");
        });
    }
    addDomain(domain, overrides) {
        return this.writeToContract("addDomain", [domain], overrides);
    }
    removeDomain(domain, overrides) {
        return this.writeToContract("removeDomain", [domain], overrides);
    }
    checkDomain(domain) {
        return ResultAsync.fromPromise(
        // returns array of domains
        this.contract.checkDomain(domain), (e) => {
            return this.generateError(e, "Unable to call checkDomain()");
        });
    }
    getRequestForDataListByRequesterAddress(requesterAddress, fromBlock, toBlock) {
        return this.queryFilter(this.filters.RequestForData(requesterAddress), fromBlock, toBlock).map((logsEvents) => {
            return logsEvents.reduce((acc, logEvent) => {
                if (logEvent instanceof ethers.EventLog) {
                    acc.push(new RequestForData(this.getContractAddress(), logEvent.args.requester, logEvent.args.ipfsCID, BlockNumber(logEvent.blockNumber)));
                }
                return acc;
            }, new Array());
        });
    }
    getRequestForDataList(fromBlock, toBlock) {
        return this.queryFilter(this.filters.RequestForDataNoOwner(), fromBlock, toBlock).map((logsEvents) => {
            return logsEvents.reduce((acc, logEvent) => {
                if (logEvent instanceof ethers.EventLog) {
                    acc.push(new RequestForData(this.getContractAddress(), logEvent.args.requester, logEvent.args.ipfsCID, BlockNumber(logEvent.blockNumber)));
                }
                return acc;
            }, new Array());
        });
    }
    disableOpenOptIn(overrides) {
        return this.writeToContract("disableOpenOptIn", [], overrides);
    }
    enableOpenOptIn(overrides) {
        return this.writeToContract("enableOpenOptIn", [], overrides);
    }
    baseURI() {
        return ResultAsync.fromPromise(this.contract.baseURI(), (e) => {
            return this.generateError(e, "Unable to call baseURI()");
        });
    }
    setBaseURI(baseUri, overrides) {
        return this.writeToContract("setBaseURI", [baseUri], overrides);
    }
    hasRole(role, address) {
        return ResultAsync.fromPromise(this.contract.hasRole(EConsentRoles[role], address), (e) => {
            return this.generateError(e, "Unable to call hasRole()");
        });
    }
    grantRole(role, address, overrides) {
        return this.writeToContract("grantRole", [role, address], overrides);
    }
    revokeRole(role, address, overrides) {
        return this.writeToContract("revokeRole", [role, address], overrides);
    }
    renounceRole(role, address, overrides) {
        return this.writeToContract("renounceRole", [role, address], overrides);
    }
    getQueryHorizon() {
        return ResultAsync.fromPromise(this.contract.queryHorizon(), (e) => {
            return this.generateError(e, "Unable to call queryHorizon()");
        }).map((queryHorizon) => BlockNumber(Number(queryHorizon)));
    }
    setQueryHorizon(blockNumber, overrides) {
        return this.writeToContract("setQueryHorizon", [blockNumber], overrides);
    }
    estimateGasLimitForSetQueryHorizon(blockNumber, overrides) {
        return ResultAsync.fromPromise(this.contract.estimateGas["setQueryHorizon"](blockNumber, {
            overrides,
        }), (e) => this.generateError(e, `Failed to estimate gas with error: ${e}`)).map((bnGas) => {
            return BigNumberString(bnGas.toString());
        });
    }
    checkCommitments(commitments) {
        // Returns the indexes of the commitments. 0 means the commitment is invalid.
        // The commitment is just a bigint, but it is less than 32 bytes. We need to convert it to a bytes32
        return ResultAsync.fromPromise(this.contract.checkCommitments(commitments.map((commitment) => {
            return ethers.toBeArray(commitment);
        })), (e) => {
            return this.generateError(e, "Unable to call checkCommitments()");
        }).andThen((indexes) => {
            // Indexes should be the same size as commitments. If not, something went wrong
            if (commitments.length != indexes.length) {
                return errAsync(new ConsentContractError("Invalid response from checkCommitments(), returned index length does not match the length of the requested commitments", null, null));
            }
            // If if the index is not 0, then the commitment is valid
            return okAsync(indexes.map((index) => {
                return Number(index);
            }));
        });
    }
    checkNonces(nonces) {
        return ResultAsync.fromPromise(this.contract.checkNonces(nonces), (e) => {
            return this.generateError(e, "Unable to call checkNonces()");
        });
    }
    fetchAnonymitySet(start, stop) {
        return ResultAsync.fromPromise(this.contract.fetchAnonymitySet(start, stop), (e) => {
            return this.generateError(e, "Unable to call fetchAnonymitySet()");
        }).map((commitmentBytes) => {
            return commitmentBytes.map((commitment) => {
                return Commitment(ethers.toBigInt(commitment));
            });
        });
    }
    // Get the number of opted in addresses
    totalSupply() {
        return ResultAsync.fromPromise(this.contract.totalSupply(), (e) => {
            return this.generateError(e, "Unable to call totalSupply()");
        }).map((totalSupply) => Number(totalSupply));
    }
    openOptInDisabled() {
        return ResultAsync.fromPromise(this.contract.openOptInDisabled(), (e) => {
            return this.generateError(e, "Unable to call openOptInDisabled()");
        });
    }
    //#region Staking
    //#region Content
    tagIndices(tag, stakingToken) {
        return ResultAsync.fromPromise(this.contract.tagIndices(tag, stakingToken), (e) => {
            return this.generateError(e, "Unable to call tagIndices()");
        }).map((index) => {
            return BigNumberString(index.toString());
        });
    }
    getNumberOfStakedTags(stakingToken) {
        return ResultAsync.fromPromise(this.contract.getNumberOfStakedTags(stakingToken), (e) => {
            return this.generateError(e, "Unable to call getNumberOfStakedTags()");
        }).map((num) => {
            return Number(num);
        });
    }
    getTagArray(stakingToken) {
        return ResultAsync.fromPromise(this.contract.getTagArray(stakingToken), (e) => {
            return this.generateError(e, "Unable to call getTagArray()");
        }).map((tags) => {
            return tags.map((tag) => {
                return new Tag(tag.slot ? BigNumberString(tag.slot.toString()) : null, tag.tag);
            });
        });
    }
    getContentAddress() {
        return ResultAsync.fromPromise(this.contract.getContentAddress(), (e) => {
            return this.generateError(e, "Unable to call getContentAddress()");
        });
    }
    //#endregion Content
    //#region Consent
    depositStake(depositToken, amount, overrides) {
        return this.writeToContract("depositStake", [depositToken, amount], overrides);
    }
    removeStake(depositToken, amount, overrides) {
        return this.writeToContract("removeStake", [depositToken, amount], overrides);
    }
    newGlobalTag(tag, stakingToken, stakeAmount, stakeSlot, overrides) {
        return this.writeToContract("newGlobalTag", [tag, stakingToken, stakeAmount, stakeSlot], overrides);
    }
    newLocalTagUpstream(tag, stakingToken, stakeAmount, newSlot, existingSlot, overrides) {
        return this.writeToContract("newLocalTagUpstream", [tag, stakingToken, stakeAmount, newSlot, existingSlot], overrides);
    }
    newLocalTagDownstream(tag, stakingToken, stakeAmount, existingSlot, newSlot, overrides) {
        return this.writeToContract("newLocalTagDownstream", [tag, stakingToken, stakeAmount, existingSlot, newSlot], overrides);
    }
    moveExistingListingUpstream(tag, stakingToken, stakeAmount, newSlot, existingSlot, overrides) {
        return this.writeToContract("moveExistingListingUpstream", [tag, stakingToken, stakeAmount, newSlot, existingSlot], overrides);
    }
    restakeExpiredListing(tag, stakingToken, overrides) {
        return this.writeToContract("restakeExpiredListing", [tag, stakingToken], overrides);
    }
    replaceExpiredListing(tag, stakingToken, stakeAmount, stakeSlot, overrides) {
        return this.writeToContract("replaceExpiredListing", [tag, stakingToken, stakeAmount, stakeSlot], overrides);
    }
    removeListing(tag, stakingToken, overrides) {
        return this.writeToContract("removeListing", [tag, stakingToken], overrides);
    }
    //#endregion Consent
    //#endregion Staking
    pause(overrides) {
        return this.writeToContract("pause", [], overrides);
    }
    unpause(overrides) {
        return this.writeToContract("unpause", [], overrides);
    }
    getSignature(values) {
        const types = ["address", "uint256"];
        return this.cryptoUtils.getSignature(this.providerOrSigner, types, values);
    }
    generateContractSpecificError(msg, e, transaction) {
        return new ConsentContractError(msg, e, transaction);
    }
};
ConsentContract = __decorate([
    injectable(),
    __metadata("design:paramtypes", [Object, String, Object])
], ConsentContract);
export { ConsentContract };
//# sourceMappingURL=ConsentContract.js.map